# DiProMagOntology

## Project Description
This ontology encompasses the semantic modeling of the entire process chain, including production, characterization, and prototypical application. 

As part of the [DiProMag](https://www.dipromag.de) project, a novel approach for ontology engineering with [OTTR](https://ottr.xyz) templates was developed. 

You can find the developed OTTR templates, OTTR instances holding real data, alongside the DiProMag ontology in this repository. 

The ontology can be created by instantiating the OTTR templates. The results of the instantiation can be found in *instances/\**. We have reduced the output to the T-Box you can find in *dipromag.ttl* with the Perl script *extract-tbox.pl*. The T-Box merged with the metadata leads to *dmco.ttl*.

The documentation for using the templates can be found in *doc_manual*. The automatically generated OTTR documentation can be found in *doc*.

The OTTR documentation can be generated by running the following commands: `java -jar lutra.jar --library template_library --fetchMissing --mode=docttrLibrary -o ./doc/ --debugStackTrace`, 

Generate ttl files: `java -jar lutra.jar --library template_library --fetchMissing --mode=formatLibrary -o ./lib_ttl/ --debugStackTrace`
Generate individual stOTTR files: `java -jar lutra.jar --library template_library --fetchMissing --mode=formatLibrary -o ./lib_stottr/ --debugStackTrace -O=stottr`


## Usage
Install [Lutra](https://gitlab.com/ottr/lutra/lutra) according to the official documentation and place the jar file inside the root folder of this repository or use the provided jar file. 

**Instantiate templates** (real data collected through experiments during DiProMag): 
`java -jar lutra.jar --library template_library/ --fetchMissing --inputFormat stottr instances/*`

**Run instantiation unit tests** (random data): 
`java -jar lutra.jar --library template_library/ --fetchMissing --inputFormat stottr unit_tests/*`

The resulting T-Box can be found in *dmco-tbox.ttl*, metadata in *metadata.ttl*, and an ontology generated through template calls with real data in *dipromag.ttl*. 

## Contributing
Andreas Hütten, Günter Reiss, Philipp Cimiano, Luana Caron, Tapas Samanta, Inga Ennen, Basil Ell, Martin Wortmann, Moritz Blum, Christian Schröder, Sonja Schöning, Simon Bekemeier, Lennart Schwan, Michael Feige, Thomas Hilbig, Alisa Chirkova.

## License
This ontology (including our OTTR Templates & Instances) is published under the [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/legalcode) license.

## Project status
Ontology version 0.1.0.

## Funding
This work was done in the context of DiProMag, a BMBF (German Federal Ministry of Education and Research) funded research project under Grant No. 13XP5120B. (Bielefeld University) and Grant No. 13XP5 120A (Bielefeld University of Applied Science and Arts).

GitLab: [Uni Bielefeld](https://gitlab.ub.uni-bielefeld.de/semantic-computing/dipromagontology)

Project website: [dipromag.de](https://www.dipromag.de)


## Citation

If you have found our ontology useful in your work, please consider citing
[our article](https://arxiv.org/abs/2309.13130):

```bibtex
@article{blum2023,
  title={Insights from an {OTTR}-centric Ontology Engineering Methodology},
  author={Blum, Moritz and Ell, Basil and Cimiano, Philipp},
  journal={Proceedings of the 14th Workshop on Ontology Design and Patterns (WOP 2023)},
  year={2023},
  doi={10.48550/arXiv.2309.13130},
  URL={https://doi.org/10.48550/arXiv.2309.13130}
}
```
